summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobileiface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmobile/kmobileiface.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmobile/kmobileiface.h')
-rw-r--r--kmobile/kmobileiface.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kmobile/kmobileiface.h b/kmobile/kmobileiface.h
index 60974b268..5d39f236c 100644
--- a/kmobile/kmobileiface.h
+++ b/kmobile/kmobileiface.h
@@ -16,40 +16,40 @@ class kmobileIface : virtual public DCOPObject
public:
k_dcop:
- virtual TQStringList deviceNames() = 0;
+ virtual TQStringList tqdeviceNames() = 0;
- virtual void removeDevice( TQString deviceName ) = 0;
- virtual void configDevice( TQString deviceName ) = 0;
+ virtual void removeDevice( TQString tqdeviceName ) = 0;
+ virtual void configDevice( TQString tqdeviceName ) = 0;
- virtual bool connectDevice( TQString deviceName ) = 0;
- virtual bool disconnectDevice( TQString deviceName ) = 0;
- virtual bool connected( TQString deviceName ) = 0;
+ virtual bool connectDevice( TQString tqdeviceName ) = 0;
+ virtual bool disconnectDevice( TQString tqdeviceName ) = 0;
+ virtual bool connected( TQString tqdeviceName ) = 0;
- virtual TQString deviceClassName( TQString deviceName ) = 0;
- virtual TQString deviceName( TQString deviceName ) = 0;
- virtual TQString revision( TQString deviceName ) = 0;
- virtual int classType( TQString deviceName ) = 0;
+ virtual TQString tqdeviceClassName( TQString tqdeviceName ) = 0;
+ virtual TQString tqdeviceName( TQString tqdeviceName ) = 0;
+ virtual TQString revision( TQString tqdeviceName ) = 0;
+ virtual int classType( TQString tqdeviceName ) = 0;
- virtual int capabilities( TQString deviceName ) = 0;
- virtual TQString nameForCap( TQString deviceName, int cap ) = 0;
+ virtual int capabilities( TQString tqdeviceName ) = 0;
+ virtual TQString nameForCap( TQString tqdeviceName, int cap ) = 0;
- virtual TQString iconFileName( TQString deviceName ) = 0;
+ virtual TQString iconFileName( TQString tqdeviceName ) = 0;
- virtual int numAddresses( TQString deviceName ) = 0;
- virtual TQString readAddress( TQString deviceName, int index ) = 0;
- virtual bool storeAddress( TQString deviceName, int index, TQString vcard, bool append ) = 0;
+ virtual int numAddresses( TQString tqdeviceName ) = 0;
+ virtual TQString readAddress( TQString tqdeviceName, int index ) = 0;
+ virtual bool storeAddress( TQString tqdeviceName, int index, TQString vcard, bool append ) = 0;
- virtual int numCalendarEntries( TQString deviceName ) = 0;
+ virtual int numCalendarEntries( TQString tqdeviceName ) = 0;
- virtual int numNotes( TQString deviceName ) = 0;
- virtual TQString readNote( TQString deviceName, int index ) = 0;
- virtual bool storeNote( TQString deviceName, int index, TQString note ) = 0;
+ virtual int numNotes( TQString tqdeviceName ) = 0;
+ virtual TQString readNote( TQString tqdeviceName, int index ) = 0;
+ virtual bool storeNote( TQString tqdeviceName, int index, TQString note ) = 0;
/*
* DCOP functions for the devices:/ kioslave
*/
k_dcop:
- virtual TQStringList kio_devices_deviceInfo(TQString deviceName) = 0;
+ virtual TQStringList kio_tqdevices_tqdeviceInfo(TQString tqdeviceName) = 0;
};
#endif // _KMOBILEIFACE_H_
@@ -16,40 +16,40 @@ class kmobileIface : virtual public DCOPObject
/*
- * DCOP functions for the devices:/ kioslave
+ * DCOP functions for the tqdevices:/ kioslave
*/
k_dcop: